<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sk_SK" sourcelanguage="en">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../ui/AboutDialog.ui" line="14"/>
        <source>About Scan Tailor</source>
        <translation>O programe Scan Tailor</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="27"/>
        <source>About</source>
        <translation>O programe</translation>
    </message>
    <message>
        <source>Scan Tailor is an interactive post-processing tool for scanned pages. It performs operations such as page splitting, skew correction, adding/removing margins, and others. You give it raw scans, and you get pages ready to be printed or assembled into a PDF or DJVU file.  Scanning and optical character recogrnition is out of scope of this project.</source>
        <translation type="obsolete">Scan Tailor je interaktívny nástroj na úpravu zoskenovaných strán. Program vie rozdeťovať dvojstrany, opraviť natočenie, nastavenie okrajov a viac. Načítate nespracované skeny a výsledok bude pripravený pre vytvorenie PDF alebo DJVU súborov. Skenovanie a OCR niesú cieľom tohoto projektu.</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="101"/>
        <source>Authors</source>
        <translation>Autori</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="125"/>
        <source>Lead Developer</source>
        <translation>Hlavný vývojár</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="157"/>
        <source>U235 - Picture auto-detection algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="164"/>
        <source>Robert B. - First generation dewarping algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="171"/>
        <source>Andrey Bergman - System load adjustment.</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../ui/AboutDialog.ui" line="178"/>
        <source>Petr Kovář - Command line interface.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="190"/>
        <source>Translators</source>
        <translation>Prekladatelia</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="205"/>
        <source>Svetoslav Sashkov, Mandor - Bulgarian</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../ui/AboutDialog.ui" line="212"/>
        <source>Petr Kovář - Czech</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="219"/>
        <source>Stefan Birkner - German</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="226"/>
        <source>Angelo Gemmi - Italian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="233"/>
        <source>Masahiro Kitagawa - Japanese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="240"/>
        <source>Patrick Pascal - French</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../ui/AboutDialog.ui" line="247"/>
        <source>Daniel Koć - Polish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="254"/>
        <source>Joseph Artsimovich - Russian</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../ui/AboutDialog.ui" line="261"/>
        <source>Marián Hvolka - Slovak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="268"/>
        <source>Flavio Benelli - Spanish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="275"/>
        <source>Davidson Wang - Traditional Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="142"/>
        <source>Contributors</source>
        <translation>Prispeli</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="282"/>
        <source>Yuri Chornoivan - Ukrainian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="294"/>
        <source>Documentation</source>
        <translation>Dokumentácia</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="309"/>
        <source>denver 22</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="350"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="33"/>
        <source>Scan Tailor is an interactive post-processing tool for scanned pages. It performs operations such as page splitting, skew correction, adding/removing margins, and others. You give it raw scans, and you get pages ready to be printed or assembled into a PDF or DJVU file.  Scanning and optical character recognition is out of scope of this project.</source>
        <translation>Scan Tailor je interaktívny nástroj na úpravu zoskenovaných strán. Program vie rozdeťovať dvojstrany, opraviť natočenie, nastavenie okrajov a viac. Načítate nespracované skeny a výsledok bude pripravený pre vytvorenie PDF alebo DJVU súborov. Skenovanie a OCR niesú cieľom tohoto projektu.</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="132"/>
        <source>Joseph Artsimovich</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>BatchProcessingLowerPanel</name>
    <message>
        <location filename="../ui/BatchProcessingLowerPanel.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/BatchProcessingLowerPanel.ui" line="36"/>
        <source>Beep when finished</source>
        <translation>Upozorniť zvukom pri ukončení</translation>
    </message>
</context>
<context>
    <name>ColorPickupInteraction</name>
    <message>
        <location filename="../filters/output/ColorPickupInteraction.cpp" line="47"/>
        <source>Click on an area to pick up its color, or ESC to cancel.</source>
        <translation>Kliknite do oblasti pre získanie  farby alebo stlačte klávesu ESC pre zrušenie.</translation>
    </message>
</context>
<context>
    <name>CrashReportDialog</name>
    <message>
        <source>Crash Report</source>
        <translation type="obsolete">Hlásenie o chybe</translation>
    </message>
    <message>
        <source>Scan Tailor crashed.  That&apos;s usually caused by errors in the software.  You can help us find and fix the problem by submitting this crash report.</source>
        <translation type="obsolete">Scan Tailor padol. To je väčšinou zapríčinené chybou v programe. Môžete nám pomôcť nájsť a opraviť problém odeslaním tohoto hlásenia.</translation>
    </message>
    <message>
        <source>Information to be sent</source>
        <translation type="obsolete">Informácie na odeslanie</translation>
    </message>
    <message>
        <source>If you have additional information, for example you know how to reproduce the crash, please provide it here.
English or Russian please.</source>
        <translation type="obsolete">Ak máte doplňujúce informácie (napríklad viete ako chybu zopakovať) napíšte ich sem. Anglicky alebo rusky.</translation>
    </message>
    <message>
        <source>If you are willing to provide further assistance to developers to help fix this problem, please provide your email address.</source>
        <translation type="obsolete">Ak chcete, aby vás vývojári mohli v prípade potreby kontaktovať, vyplňte prosím svoju e-mailovú adresu.</translation>
    </message>
    <message>
        <source>Email [optional]</source>
        <translation type="obsolete">Email [voliteľné]</translation>
    </message>
    <message>
        <source>This file contains the internal state of the program when it crashed</source>
        <translation type="obsolete">Tento súbor obsahuje stav programu pri páde</translation>
    </message>
    <message>
        <source>Dump file</source>
        <translation type="obsolete">Obsah súboru</translation>
    </message>
    <message>
        <source>Sending ...</source>
        <translation type="obsolete">Odosielanie ...</translation>
    </message>
    <message>
        <source>Unexpected response (code %1) from dispatcher</source>
        <translation type="obsolete">Neočakávaná chyba (code %1) na strane odosielateľa</translation>
    </message>
    <message>
        <source>Unexpected response from dispatcher</source>
        <translation type="obsolete">Neočakávaná chyba na strane príjemcu</translation>
    </message>
    <message>
        <source>Unexpected response (code %1) from the receiving side</source>
        <translation type="obsolete">Neočakávaná chyba (code %1) na strane príjemcu</translation>
    </message>
    <message>
        <source>Successfully sent</source>
        <translation type="obsolete">Úspešne odoslané</translation>
    </message>
</context>
<context>
    <name>DeskewApplyDialog</name>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="20"/>
        <source>Apply to</source>
        <translation>Použiť na</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="26"/>
        <source>This page only (already applied)</source>
        <translation>Len pre túto stranu (už použité)</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="36"/>
        <source>All pages</source>
        <translation>Všetky strany</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="43"/>
        <source>This page and the following ones</source>
        <translation>Táto a nasledujúce strany</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="59"/>
        <source>Selected pages</source>
        <translation>Vybrané strany</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="92"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>Pre výber viacerých strán použite Ctr+Klik / Shift+Klik.</translation>
    </message>
</context>
<context>
    <name>DeskewOptionsWidget</name>
    <message>
        <location filename="../filters/deskew/ui/DeskewOptionsWidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewOptionsWidget.ui" line="20"/>
        <source>Deskew</source>
        <translation>Natočenie</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewOptionsWidget.ui" line="41"/>
        <source>Auto</source>
        <translation>Automaticky</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewOptionsWidget.ui" line="57"/>
        <source>Manual</source>
        <translation>Ručne</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewOptionsWidget.ui" line="140"/>
        <source>Apply To ...</source>
        <translation>Použiť na ...</translation>
    </message>
</context>
<context>
    <name>DragHandler</name>
    <message>
        <location filename="../interaction/DragHandler.cpp" line="46"/>
        <source>Unrestricted dragging is possible by holding down the Shift key.</source>
        <translation>Neobmedzené posúvanie strany je možné, ak pridržíte klávesu Shift.</translation>
    </message>
</context>
<context>
    <name>FixDpiDialog</name>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="13"/>
        <source>Fix DPI</source>
        <translation>Opraviť DPI</translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="23"/>
        <source>Tab 1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="33"/>
        <source>Tab 2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="46"/>
        <source>DPI</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="69"/>
        <source>Custom</source>
        <translation>Vlastné</translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="90"/>
        <source>x</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="113"/>
        <source>Apply</source>
        <translation>Použiť</translation>
    </message>
    <message>
        <source>Need Fixing</source>
        <translation type="obsolete">Nutná oprava</translation>
    </message>
    <message>
        <source>All Pages</source>
        <translation type="obsolete">Všetky strany</translation>
    </message>
    <message>
        <source>DPI is too large and most likely wrong.</source>
        <translation type="obsolete">DPI je príliš vysoké a pravdepodobne nesprávne.</translation>
    </message>
    <message>
        <source>DPI is too small. Even if it&apos;s correct, you are not going to get acceptable results with it.</source>
        <translation type="obsolete">DPI je príliš nízke. Môže byť správne, dostanete však neakceptovateľný výsledok.</translation>
    </message>
    <message>
        <source>DPI is too small for this pixel size. Such combination would probably lead to out of memory errors.</source>
        <translation type="obsolete">DPI je príliš nízke vzhľadom k počtu pixelov a pravdepodobne by to viedlo k nedostatku pamäti.</translation>
    </message>
    <message>
        <source>%1 (page %2)</source>
        <translation type="obsolete">%1 (strana %2)</translation>
    </message>
</context>
<context>
    <name>FixDpiSinglePageDialog</name>
    <message>
        <source>Fix DPI</source>
        <translation type="obsolete">Oprava DPI</translation>
    </message>
    <message>
        <source>DPI for %1</source>
        <translation type="obsolete">DPI pre %1</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation type="obsolete">Vlastné</translation>
    </message>
    <message>
        <source>%1 (page %2)</source>
        <translation type="obsolete">%1 (strana %2)</translation>
    </message>
    <message>
        <source>DPI is too large and most likely wrong.</source>
        <translation type="obsolete">DPI je príliš vysoké a pravdepodobne nesprávne.</translation>
    </message>
    <message>
        <source>DPI is too small. Even if it&apos;s correct, you are not going to get acceptable results with it.</source>
        <translation type="obsolete">DPI je príliš nízke. Môže byť správne, dostanete však neakceptovateľný výsledok.</translation>
    </message>
    <message>
        <source>DPI is too small for this pixel size. Such combination would probably lead to out of memory errors.</source>
        <translation type="obsolete">DPI je príliš nízke vzhľadom k počtu pixelov a pravdepodobne by to viedlo k nedostatku pamäti.</translation>
    </message>
</context>
<context>
    <name>ImageViewBase</name>
    <message>
        <source>Use the mouse wheel or +/- to zoom.  When zoomed, dragging is possible.</source>
        <translation type="obsolete">Pre priblíženie použite koliečko myši alebo klávesu + resp. -. Aj po zväčšení je možné stranu ťahaním posúvať.</translation>
    </message>
</context>
<context>
    <name>InteractiveXSpline</name>
    <message>
        <location filename="../interaction/InteractiveXSpline.cpp" line="47"/>
        <source>Click to create a new control point.</source>
        <translation>Nový kontrolný bod vytvoríte kliknutím.</translation>
    </message>
    <message>
        <location filename="../interaction/InteractiveXSpline.cpp" line="73"/>
        <source>This point can be dragged.</source>
        <translation>S týmto bodom môžete hýbať.</translation>
    </message>
    <message>
        <location filename="../interaction/InteractiveXSpline.cpp" line="75"/>
        <source>Drag this point or delete it by pressing Del or D.</source>
        <translation>Posuňte tento bod alebo ho zmažte klávesou Del nebo D.</translation>
    </message>
</context>
<context>
    <name>LoadFileTask</name>
    <message>
        <source>The following file could not be loaded:
%1</source>
        <translation type="obsolete">Tento súbor nemohl byť načítaný: 
%1</translation>
    </message>
</context>
<context>
    <name>LoadFilesStatusDialog</name>
    <message>
        <location filename="../ui/LoadFilesStatusDialog.ui" line="14"/>
        <source>Some files failed to load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/LoadFilesStatusDialog.ui" line="27"/>
        <source>Loaded successfully: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/LoadFilesStatusDialog.ui" line="87"/>
        <source>Failed to load: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ui/MainWindow.ui" line="20"/>
        <source>MainWindow</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="130"/>
        <source>Keep current page in view.</source>
        <translation>Ponechať zobrazenú aktuálnu stranu.</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="156"/>
        <source>Use Home, End, PgUp (or Q), PgDown (or W) to navigate between pages.</source>
        <translation>K presunu medzi stranami slúžia klávesy Home, End PgUp (alebo Q), PgDown (alebo W).</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="185"/>
        <source>Tools</source>
        <translation>Nástroje</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="196"/>
        <source>File</source>
        <translation>Súbor</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="210"/>
        <source>Help</source>
        <translation>Pomocník</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation type="obsolete">Ladenie</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="227"/>
        <source>Debug Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="232"/>
        <source>Save Project</source>
        <translation>Uložiť projekt</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="235"/>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="240"/>
        <source>Save Project As ...</source>
        <translation>Uložiť projekt ako ...</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="245"/>
        <location filename="../ui/MainWindow.ui" line="294"/>
        <source>Next Page</source>
        <translation>Ďalšia strana</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="248"/>
        <source>PgDown</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="256"/>
        <location filename="../ui/MainWindow.ui" line="283"/>
        <source>Previous Page</source>
        <translation>Predošlá strana</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="259"/>
        <source>PgUp</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="267"/>
        <source>New Project ...</source>
        <translation>Nový projekt ...</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="270"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="275"/>
        <source>Open Project ...</source>
        <translation>Otvoriť projekt ...</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="278"/>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="286"/>
        <source>Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="297"/>
        <source>W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="305"/>
        <source>Close Project</source>
        <translation>Zatvoriť projekt</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="308"/>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="313"/>
        <source>Quit</source>
        <translation>Koniec</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="316"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="321"/>
        <source>Settings ...</source>
        <translation>Nastavenie...</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="326"/>
        <source>First Page</source>
        <translation>Prvá strana</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="329"/>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="334"/>
        <source>Last Page</source>
        <translation>Posledná strana</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="337"/>
        <source>End</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="342"/>
        <source>About</source>
        <translation>O programe</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="347"/>
        <source>Fix DPI ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="352"/>
        <source>Relinking ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop batch processing</source>
        <translation type="obsolete">Zastaviť dávkové spracovanie</translation>
    </message>
    <message>
        <source>Save this project?</source>
        <translation type="obsolete">Uložiť projekt?</translation>
    </message>
    <message>
        <source>Insert before ...</source>
        <translation type="obsolete">Vložiť pred ...</translation>
    </message>
    <message>
        <source>Insert after ...</source>
        <translation type="obsolete">Vložiť za ...</translation>
    </message>
    <message>
        <source>Remove from project ...</source>
        <translation type="obsolete">Odstrániť z projektu ...</translation>
    </message>
    <message>
        <source>Insert here ...</source>
        <translation type="obsolete">Vložiť sem ...</translation>
    </message>
    <message>
        <source>Scan Tailor Projects</source>
        <translation type="obsolete">Zoznam projektov</translation>
    </message>
    <message>
        <source>Open Project</source>
        <translation type="obsolete">Otvoriť projekt</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="obsolete">Chyba</translation>
    </message>
    <message>
        <source>Unable to open the project file.</source>
        <translation type="obsolete">Nemožno otvoriť súbor s projektom.</translation>
    </message>
    <message>
        <source>The project file is broken.</source>
        <translation type="obsolete">Súbor s projektom je poškodený.</translation>
    </message>
    <message>
        <source>Output is not yet possible, as the final size of pages is not yet known.
To determine it, run batch processing at &quot;Select Content&quot; or &quot;Margins&quot;.</source>
        <translation type="obsolete">Výstup zatiaľ nie je možný, lebo ešte nie je známa konečná veľkosť strán.
Na určenie veľkosti strán spustite dávkové spracovanie pre &quot;Vybrat Obsah&quot; alebo &quot;Okraje&quot;.</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation type="obsolete">Nepomenovaný</translation>
    </message>
    <message>
        <source>Error saving the project file!</source>
        <translation type="obsolete">Chyba pri ukladaní súboru s projektom!</translation>
    </message>
    <message>
        <source>File to insert</source>
        <translation type="obsolete">Súbor na vloženie</translation>
    </message>
    <message>
        <source>Images not in project (%1)</source>
        <translation type="obsolete">Obrázky, ktoré nie sú v projekte (%1)</translation>
    </message>
    <message>
        <source>Error opening the image file.</source>
        <translation type="obsolete">Chyba pri otváraní súboru s obrázkom.</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="obsolete">Odstrániť</translation>
    </message>
</context>
<context>
    <name>NewOpenProjectPanel</name>
    <message>
        <location filename="../ui/NewOpenProjectPanel.ui" line="19"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/NewOpenProjectPanel.ui" line="52"/>
        <source>New Project ...</source>
        <translation>Nový projekt ...</translation>
    </message>
    <message>
        <location filename="../ui/NewOpenProjectPanel.ui" line="78"/>
        <source>Open Project ...</source>
        <translation>Otvoriť projekt ...</translation>
    </message>
    <message>
        <location filename="../ui/NewOpenProjectPanel.ui" line="103"/>
        <source>Recent Projects</source>
        <translation>Posledné otvorené projekty</translation>
    </message>
</context>
<context>
    <name>OrientationApplyDialog</name>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="17"/>
        <source>Fix Orientation</source>
        <translation>Opraviť orientáciu</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="23"/>
        <source>Apply to</source>
        <translation>Použiť na</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="29"/>
        <source>This page only (already applied)</source>
        <translation>Len na túto stranu (už použité)</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="39"/>
        <source>All pages</source>
        <translation>Všetky strany</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="46"/>
        <source>This page and the following ones</source>
        <translation>Táto a následujúce strany</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="71"/>
        <source>Every other page</source>
        <extracomment>All odd or even pages, depending on the current page being odd or even.</extracomment>
        <translation>Každá druhá strana</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="101"/>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="206"/>
        <source>The current page will be included.</source>
        <translation>Aktuálna strana bude zahrnutá.</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="125"/>
        <source>Selected pages</source>
        <translation>Vybrané strany</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="155"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>Pre výber viacerých strán použite Ctr+Klik / Shift+Klik.</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="176"/>
        <source>Every other selected page</source>
        <translation>Každá druhá vybraná strana</translation>
    </message>
</context>
<context>
    <name>OrientationOptionsWidget</name>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="13"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="19"/>
        <source>Rotate</source>
        <translation>Otočiť</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="40"/>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="56"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="142"/>
        <source>Reset</source>
        <translation>Obnoviť</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="167"/>
        <source>Scope</source>
        <translation>Rozsah</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="188"/>
        <source>Apply to ...</source>
        <translation>Použiť na ...</translation>
    </message>
</context>
<context>
    <name>OutOfMemoryDialog</name>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="14"/>
        <source>Out of memory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="37"/>
        <source>Out of Memory Situation in Scan Tailor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="70"/>
        <source>Possible reasons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="103"/>
        <source>Did you have to fix the DPI of your source images? Are you sure the values you entered were correct?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="123"/>
        <source>Sometimes your source images may have wrong DPI embedded into them. Scan Tailor tries to detect those, but it&apos;s not always easy to tell. You may need to check &quot;Fix DPI even if they look normal&quot; when creating a project and look into &quot;All pages&quot; tab in the &quot;Fix DPI&quot; dialog, which is also accessible from the Tools menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="143"/>
        <source>Is your output DPI set too high? Usually you don&apos;t need it higher than 600.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="174"/>
        <source>What can help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="204"/>
        <source>Fix your DPIs. Learn how to &lt;a href=&quot;http://vimeo.com/12524529&quot;&gt;estimate unknown DPIs&lt;/a&gt;.</source>
        <extracomment>Feel free to change the URL to a localized video / text tutorial.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="224"/>
        <source>If your hardware and operating system are 64-bit capable, consider switching to a 64-bit version of Scan Tailor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="244"/>
        <source>When working with grayscale images, make sure they are really grayscale. If they are actually color images that just happen to look grayscale, convert them to grayscale using some kind of batch image converter. This will both save memory and increase performance.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="264"/>
        <source>As a last resort, you can save some memory by making sure thumbnails are pre-created rather than created on demand. This can be done by slowly scrolling the thumbnail list all the way from top to bottom before starting any real work.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="295"/>
        <source>What won&apos;t help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="325"/>
        <source>Surprisingly, upgrading your RAM won&apos;t help here. The lack of RAM is compensated by the swap mechanism, which makes things slow, but keeps programs running. An out of memory situation means we ran out of memory address space, which has nothing to do with the amount of RAM you have. The only way to increase the memory address space is to go 64-bit hardware, 64-bit operating system and 64-bit Scan Tailor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="361"/>
        <source>Save Project</source>
        <translation type="unfinished">Uložiť projekt</translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="384"/>
        <source>Save Project As ...</source>
        <translation type="unfinished">Uložiť projekt ako ...</translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="404"/>
        <source>Don&apos;t Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="421"/>
        <source>Project Saved Successfully</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="453"/>
        <source>Please note that while Scan Tailor tries to catch out-of-memory situations and give you the opportunity to save your project, it&apos;s not always possible. This time it succeeded, but the next time it might just crash.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OutputApplyColorsDialog</name>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="17"/>
        <source>Apply Mode</source>
        <translation>Mód použitia</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="23"/>
        <source>Apply to</source>
        <translation>Použiť na</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="29"/>
        <source>This page only (already applied)</source>
        <translation>Len na túto stranu (už použité)</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="39"/>
        <source>All pages</source>
        <translation>Všetky strany</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="46"/>
        <source>This page and the following ones</source>
        <translation>Táto a nasledujúce strany</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="62"/>
        <source>Selected pages</source>
        <translation>Vybrané strany</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="95"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>Pre výber viacerých strán použite Ctr+Klik / Shift+Klik.</translation>
    </message>
</context>
<context>
    <name>OutputChangeDewarpingDialog</name>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="17"/>
        <source>Apply Dewarping Mode</source>
        <translation>Použiť mód deformácie</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="23"/>
        <source>Mode</source>
        <translation>Mód</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="29"/>
        <source>Off</source>
        <translation>Vypnuté</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="42"/>
        <source>Auto (experimental)</source>
        <translation>Automaticky (experimentálne)</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="49"/>
        <source>Manual</source>
        <translation>Ručne</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="59"/>
        <source>Scope</source>
        <translation>Rozsah</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="65"/>
        <source>This page only</source>
        <translation>Len na túto stranu</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="75"/>
        <source>All pages</source>
        <translation>Všetky strany</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="82"/>
        <source>This page and the following ones</source>
        <translation>Táto a nasledujúce strany</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="98"/>
        <source>Selected pages</source>
        <translation>Vybrané strany</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="131"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>Pre výber viacerých strán použite Ctr+Klik / Shift+Klik.</translation>
    </message>
</context>
<context>
    <name>OutputChangeDpiDialog</name>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="17"/>
        <source>Apply Output Resolution</source>
        <translation>Použiť výstupné rozlíšenie</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="23"/>
        <source>DPI</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="68"/>
        <source>Scope</source>
        <translation>Rozsah</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="74"/>
        <source>This page only</source>
        <translation>Len na tuto stranu</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="84"/>
        <source>All pages</source>
        <translation>Všetky strany</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="91"/>
        <source>This page and the following ones</source>
        <translation>Táto a nasledujúce strany</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="107"/>
        <source>Selected pages</source>
        <translation>Vybrané strany</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="140"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>Pre výber viacerých strán použite Ctr+Klik / Shift+Klik.</translation>
    </message>
</context>
<context>
    <name>OutputOptionsWidget</name>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="20"/>
        <source>Output Resolution (DPI)</source>
        <translation>Výstupné rozlíšenie (DPI)</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="78"/>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="419"/>
        <source>Change ...</source>
        <translation>Zmeniť ...</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="103"/>
        <source>Mode</source>
        <translation>Mód</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="169"/>
        <source>White margins</source>
        <translation>Biele okraje</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="176"/>
        <source>Equalize illumination</source>
        <translation>Kompenzovať osvetlenie</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="274"/>
        <source>Thinner</source>
        <translation>Tenšie</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="306"/>
        <source>Thicker</source>
        <translation>Hrubšie</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="336"/>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="484"/>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="666"/>
        <source>Apply To ...</source>
        <translation>Použiť na ...</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="361"/>
        <source>Dewarping</source>
        <translation>Deformácie</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="444"/>
        <source>Depth perception</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="509"/>
        <source>Despeckling</source>
        <translation>Čistenie</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="533"/>
        <source>No despeckling</source>
        <translation>Bez čistenia</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="558"/>
        <source>Cautious despeckling</source>
        <translation>Opatrné čistenie</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="561"/>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="587"/>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="613"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="584"/>
        <source>Normal despeckling</source>
        <translation>Normálne čistenie</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="610"/>
        <source>Aggressive despeckling</source>
        <translation>Agresívne čistenie</translation>
    </message>
</context>
<context>
    <name>PageLayoutApplyDialog</name>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="20"/>
        <source>Apply to</source>
        <translation>Použiť na</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="26"/>
        <source>This page only (already applied)</source>
        <translation>Len na túto stranu (už použité)</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="36"/>
        <source>All pages</source>
        <translation>Všetky strany</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="43"/>
        <source>This page and the following ones</source>
        <translation>Táto a nasledujúce strany</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="59"/>
        <source>Every other page</source>
        <extracomment>All odd or even pages, depending on the current page being odd or even.</extracomment>
        <translation type="unfinished">Každá druhá strana</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="89"/>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="194"/>
        <source>The current page will be included.</source>
        <translation type="unfinished">Aktuálna strana bude zahrnutá.</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="110"/>
        <source>Selected pages</source>
        <translation>Vybrané strany</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="143"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>Pre výber viacerých strán použite Ctr+Klik / Shift+Klik.</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="164"/>
        <source>Every other selected page</source>
        <translation type="unfinished">Každá druhá vybraná strana</translation>
    </message>
</context>
<context>
    <name>PageLayoutOptionsWidget</name>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="20"/>
        <source>Margins</source>
        <translation>Okraje</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="42"/>
        <source>Millimeters (mm)</source>
        <translation>Milimetre (mm)</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="47"/>
        <source>Inches (in)</source>
        <translation>Palce (in)</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="87"/>
        <source>Top</source>
        <translation>Hore</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="100"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="161"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="338"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="361"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="384"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="407"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="430"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="456"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="479"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="502"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="525"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="121"/>
        <source>Bottom</source>
        <translation>Dolu</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="138"/>
        <source>Left</source>
        <translation>Vľavo</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="185"/>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="244"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="580"/>
        <source>Apply To ...</source>
        <translation>Použiť na ...</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="269"/>
        <source>Alignment</source>
        <translation>Zarovnanie</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="293"/>
        <source>Match size with other pages</source>
        <translation>Rovnaká veľkosť ako ostatné strany</translation>
    </message>
</context>
<context>
    <name>PageSplitModeDialog</name>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="17"/>
        <source>Split Pages</source>
        <translation>Rozdeliť strany</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="63"/>
        <source>Mode</source>
        <translation>Mód</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="69"/>
        <source>Auto</source>
        <translation>Automaticky</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="79"/>
        <source>Manual</source>
        <translation>Ručne</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="89"/>
        <source>Scope</source>
        <translation>Rozsah</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="95"/>
        <source>This page only</source>
        <translation>Len na túto stranu</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="105"/>
        <source>All pages</source>
        <translation>Všetky strany</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="112"/>
        <source>This page and the following ones</source>
        <translation>Táto a nasledujúce strany</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="128"/>
        <source>Selected pages</source>
        <translation>Vybrané strany</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="161"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>Pre výber viacerých strán použite Ctr+Klik / Shift+Klik.</translation>
    </message>
</context>
<context>
    <name>PageSplitOptionsWidget</name>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="20"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="26"/>
        <source>Page Layout</source>
        <translation>Rozvrhnutie strany</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="134"/>
        <source>?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="159"/>
        <source>Change ...</source>
        <translation>Zmeniť ...</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="184"/>
        <source>Split Line</source>
        <translation>Deliaca čiara</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="214"/>
        <source>Auto</source>
        <translation>Automaticky</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="230"/>
        <source>Manual</source>
        <translation>Ručne</translation>
    </message>
</context>
<context>
    <name>PictureZonePropDialog</name>
    <message>
        <location filename="../filters/output/ui/PictureZonePropDialog.ui" line="14"/>
        <source>Zone Properties</source>
        <translation>Vlastnosti zóny</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/PictureZonePropDialog.ui" line="20"/>
        <source>Subtract from all layers</source>
        <translation>Odobrať zo všetkých vrstiev</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/PictureZonePropDialog.ui" line="27"/>
        <source>Add to auto layer</source>
        <translation>Pridať k automatickej vrstve</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/PictureZonePropDialog.ui" line="34"/>
        <source>Subtract from auto layer</source>
        <translation>Odobrať z automatickej vrstvy</translation>
    </message>
</context>
<context>
    <name>ProjectFilesDialog</name>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="14"/>
        <source>Project Files</source>
        <translation>Súbory s projektami</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="20"/>
        <source>Input Directory</source>
        <translation>Vstupný adresár</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="33"/>
        <location filename="../ui/ProjectFilesDialog.ui" line="52"/>
        <source>Browse</source>
        <translation>Prezerať</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="43"/>
        <source>Output Directory</source>
        <translation>Výstupný adresár</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="64"/>
        <source>Files Not In Project</source>
        <translation>Súbory, ktoré nie sú v projekte</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="77"/>
        <location filename="../ui/ProjectFilesDialog.ui" line="159"/>
        <source>Select All</source>
        <translation>Vybrat všetko</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="102"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Add selected files to project.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Pridať vybrané súbory do projektu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="108"/>
        <source>&gt;&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="115"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Remove selected files from project.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Odstrániť vybrané súbory z projektu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="121"/>
        <source>&lt;&lt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="143"/>
        <source>Files In Project</source>
        <translation>Súbory v projekte</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="171"/>
        <source>Right to left layout (for Hebrew and Arabic)</source>
        <translation>Sprava doľava (Hebrejčina, Arabčina)</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="178"/>
        <source>Fix DPIs, even if they look OK</source>
        <translation>Opraviť DPI</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="obsolete">Chyba</translation>
    </message>
    <message>
        <source>No files in project!</source>
        <translation type="obsolete">Projekt nemá žiadne súbory!</translation>
    </message>
    <message>
        <source>Input directory is not set or doesn&apos;t exist.</source>
        <translation type="obsolete">Vstupný adresár nie je nastavený alebo neexistuje.</translation>
    </message>
    <message>
        <source>Input and output directories can&apos;t be the same.</source>
        <translation type="obsolete">Vstupné a výstupné adresáre musia byť rôzne.</translation>
    </message>
    <message>
        <source>Create Directory?</source>
        <translation type="obsolete">Vytvoriť adresár?</translation>
    </message>
    <message>
        <source>Output directory doesn&apos;t exist.  Create it?</source>
        <translation type="obsolete">Výstupný adresár neexistuje. Vytvoriť?</translation>
    </message>
    <message>
        <source>Unable to create output directory.</source>
        <translation type="obsolete">Nedá sa vytvoriť výstupný adresár.</translation>
    </message>
    <message>
        <source>Output directory is not set or doesn&apos;t exist.</source>
        <translation type="obsolete">Výstupný adresár nie je nastavený alebo neexistuje.</translation>
    </message>
    <message>
        <source>Some of the files failed to load.
Either we don&apos;t support their format, or they are broken.
You should remove them from the project.</source>
        <translation type="obsolete">Niektoré súbory sa nenačítali.
Buď nepodporujeme ich formát, alebo sú poškodené.
Vyraďte ich z projektu.</translation>
    </message>
</context>
<context>
    <name>ProjectOpeningContext</name>
    <message>
        <source>Error</source>
        <translation type="obsolete">Chyba</translation>
    </message>
    <message>
        <source>Unable to interpret the project file.</source>
        <translation type="obsolete">Chyba pri čítaní súboru s projektom.</translation>
    </message>
</context>
<context>
    <name>RelinkingDialog</name>
    <message>
        <location filename="../ui/RelinkingDialog.ui" line="14"/>
        <source>Relinking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/RelinkingDialog.ui" line="97"/>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/RelinkingDialog.ui" line="100"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RemovePagesDialog</name>
    <message>
        <location filename="../ui/RemovePagesDialog.ui" line="14"/>
        <source>Remove Pages</source>
        <translation>Vyradiť strany</translation>
    </message>
    <message>
        <location filename="../ui/RemovePagesDialog.ui" line="57"/>
        <source>Remove %1 page(s) from project?</source>
        <translation>Vyradiť %1 strán z projektu?</translation>
    </message>
    <message>
        <location filename="../ui/RemovePagesDialog.ui" line="72"/>
        <source>Corresponding output files will be deleted, while input files will remain.</source>
        <translation>Príslušné výstupné súbory budú zmazané, vstupné zostanú.</translation>
    </message>
</context>
<context>
    <name>SelectContentApplyDialog</name>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="17"/>
        <source>Select Content</source>
        <translation>Vybrať obsah</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="23"/>
        <source>Apply to</source>
        <translation>Použiť na</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="29"/>
        <source>This page only (already applied)</source>
        <translation>Len na túto stranu (už použité)</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="39"/>
        <source>All pages</source>
        <translation>Všetky strany</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="46"/>
        <source>This page and the following ones</source>
        <translation>Táto a nasledujúce strany</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="71"/>
        <source>Every other page</source>
        <extracomment>All odd or even pages, depending on the current page being odd or even.</extracomment>
        <translation>Každá druhá strana</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="101"/>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="206"/>
        <source>The current page will be included.</source>
        <translation>Aktuálna strana bude zahrnutá.</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="125"/>
        <source>Selected pages</source>
        <translation>Vybrané strany</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="155"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>Pre výber viacerých strán použite Ctr+Klik / Shift+Klik.</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="176"/>
        <source>Every other selected page</source>
        <translation>Každá druhá vybraná strana</translation>
    </message>
</context>
<context>
    <name>SelectContentOptionsWidget</name>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="13"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="19"/>
        <source>Content Box</source>
        <translation>Obsah</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="38"/>
        <source>Auto</source>
        <translation>Automaticky</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="54"/>
        <source>Manual</source>
        <translation>Ručne</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="83"/>
        <source>Scope</source>
        <translation>Rozsah</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="104"/>
        <source>Apply to ...</source>
        <translation>Použiť na ...</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../ui/SettingsDialog.ui" line="14"/>
        <source>Settings</source>
        <translation>Nastavenie</translation>
    </message>
    <message>
        <location filename="../ui/SettingsDialog.ui" line="20"/>
        <source>Use 3D acceleration for user interface</source>
        <translation>Používať 3D akceleráciu pre použivateľské rozhranie</translation>
    </message>
    <message>
        <source>Compiled without OpenGL support.</source>
        <translation type="obsolete">Skompilované bez podpory OpenGL.</translation>
    </message>
    <message>
        <source>Your hardware / driver don&apos;t provide the necessary features.</source>
        <translation type="obsolete">Váš hardvér nemá potrebné vlastnosti.</translation>
    </message>
</context>
<context>
    <name>StageListView</name>
    <message>
        <source>Launch batch processing</source>
        <translation type="obsolete">Spustiť dávkové spracovanie</translation>
    </message>
</context>
<context>
    <name>SystemLoadWidget</name>
    <message>
        <location filename="../ui/SystemLoadWidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/SystemLoadWidget.ui" line="23"/>
        <source>System load</source>
        <translation>Systémová záťaž</translation>
    </message>
    <message>
        <location filename="../ui/SystemLoadWidget.ui" line="46"/>
        <location filename="../ui/SystemLoadWidget.ui" line="73"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <source>Minimal</source>
        <translation type="obsolete">Minimálna</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="obsolete">Normálna</translation>
    </message>
</context>
<context>
    <name>ThumbnailSequence</name>
    <message>
        <source>%1 (page %2)</source>
        <translation type="obsolete">%1 (strana %2)</translation>
    </message>
</context>
<context>
    <name>ZoneContextMenuInteraction</name>
    <message>
        <location filename="../zones/ZoneContextMenuInteraction.cpp" line="249"/>
        <source>Delete confirmation</source>
        <translation>Potvrdenie zmazania</translation>
    </message>
    <message>
        <location filename="../zones/ZoneContextMenuInteraction.cpp" line="249"/>
        <source>Really delete this zone?</source>
        <translation>Naozaj chcete zmazať túto zónu?</translation>
    </message>
    <message>
        <location filename="../zones/ZoneContextMenuInteraction.cpp" line="265"/>
        <source>Delete</source>
        <translation>Zmazať</translation>
    </message>
    <message>
        <location filename="../zones/ZoneContextMenuInteraction.cpp" line="275"/>
        <source>Properties</source>
        <translation>Vlastnosti</translation>
    </message>
</context>
<context>
    <name>ZoneCreationInteraction</name>
    <message>
        <location filename="../zones/ZoneCreationInteraction.cpp" line="206"/>
        <source>Click to finish this zone.  ESC to cancel.</source>
        <translation>Kliknite pre uzatvorenie zóny. ESC pre zrušenie.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneCreationInteraction.cpp" line="208"/>
        <source>Connect first and last points to finish this zone.  ESC to cancel.</source>
        <translation>Spojiť prvý a posledný bod pre uzatvorenie zóny. ESC pre zrušenie.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneCreationInteraction.cpp" line="211"/>
        <source>Zones need to have at least 3 points.  ESC to cancel.</source>
        <translation>Zóna musí mať aspoň 3 body. ESC pre zrušenie.</translation>
    </message>
</context>
<context>
    <name>ZoneDefaultInteraction</name>
    <message>
        <location filename="../zones/ZoneDefaultInteraction.cpp" line="45"/>
        <source>Drag the vertex.</source>
        <translation>Posunúť vrchol.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneDefaultInteraction.cpp" line="46"/>
        <source>Click to create a new vertex here.</source>
        <translation>Kliknutím vytvoríte nový vrchol.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneDefaultInteraction.cpp" line="47"/>
        <source>Right click to edit zone properties.</source>
        <translation>Kliknite pravým tlačítkom pre editáciu vlastností zóny.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneDefaultInteraction.cpp" line="49"/>
        <source>Click to start creating a new picture zone.</source>
        <translation>Klikom začnite vytvárať novú zónu obrázka.</translation>
    </message>
</context>
<context>
    <name>ZoneVertexDragInteraction</name>
    <message>
        <location filename="../zones/ZoneVertexDragInteraction.cpp" line="160"/>
        <source>Merge these two vertices.</source>
        <translation>Zlúčiť vrcholy.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneVertexDragInteraction.cpp" line="162"/>
        <source>Move the vertex to one of its neighbors to merge them.</source>
        <translation>Zlúčiť vrchol s jedným z jeho susedov.</translation>
    </message>
</context>
<context>
    <name>deskew::Filter</name>
    <message>
        <location filename="../filters/deskew/Filter.cpp" line="57"/>
        <source>Deskew</source>
        <translation>Natočenie</translation>
    </message>
</context>
<context>
    <name>deskew::ImageView</name>
    <message>
        <location filename="../filters/deskew/ImageView.cpp" line="62"/>
        <source>Use Ctrl+Wheel to rotate or Ctrl+Shift+Wheel for finer rotation.</source>
        <translation>Použite Ctrl+Koliečko pre otáčanie alebo Ctr+Shift+Koliečko pre jemné otáčanie.</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ImageView.cpp" line="65"/>
        <source>Drag this handle to rotate the image.</source>
        <translation>Ťahajte pre natočenie obrázku.</translation>
    </message>
</context>
<context>
    <name>deskew::OptionsWidget</name>
    <message>
        <location filename="../filters/deskew/OptionsWidget.cpp" line="69"/>
        <source>Apply Deskew</source>
        <translation>Použiť natočenie</translation>
    </message>
</context>
<context>
    <name>fix_orientation::ApplyDialog</name>
    <message>
        <location filename="../filters/fix_orientation/ApplyDialog.cpp" line="53"/>
        <source>Can&apos;t do: more than one group is selected.</source>
        <translation>Nemožno vykonať: je vybraná viac než jedna skupina.</translation>
    </message>
</context>
<context>
    <name>fix_orientation::Filter</name>
    <message>
        <location filename="../filters/fix_orientation/Filter.cpp" line="64"/>
        <source>Fix Orientation</source>
        <translation>Opraviť orientáciu</translation>
    </message>
</context>
<context>
    <name>output::ChangeDpiDialog</name>
    <message>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="72"/>
        <source>Custom</source>
        <translation>Vlastné</translation>
    </message>
    <message>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="131"/>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="140"/>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="148"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="132"/>
        <source>DPI is not set.</source>
        <translation>DPI nie je nastavené.</translation>
    </message>
    <message>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="141"/>
        <source>DPI is too low!</source>
        <translation>DPI je príliš nízke!</translation>
    </message>
    <message>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="149"/>
        <source>DPI is too high!</source>
        <translation>DPI je príliš vysoké!</translation>
    </message>
</context>
<context>
    <name>output::FillZoneEditor</name>
    <message>
        <location filename="../filters/output/FillZoneEditor.cpp" line="226"/>
        <source>Pick color</source>
        <translation>Vyberte farbu</translation>
    </message>
</context>
<context>
    <name>output::Filter</name>
    <message>
        <location filename="../filters/output/Filter.cpp" line="63"/>
        <source>Output</source>
        <translation>Výstup</translation>
    </message>
</context>
<context>
    <name>output::OptionsWidget</name>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="63"/>
        <source>Black and White</source>
        <translation>Čierna a biela</translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="64"/>
        <source>Color / Grayscale</source>
        <translation>Farebné / Stupne šedej</translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="65"/>
        <source>Mixed</source>
        <translation>Zmiešané</translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="407"/>
        <source>Apply Despeckling Level</source>
        <translation>Použiť úroveň čistenia</translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="487"/>
        <source>Apply Depth Perception</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="660"/>
        <source>Off</source>
        <translation>Vypnuté</translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="663"/>
        <source>Auto</source>
        <translation>Automaticky</translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="666"/>
        <source>Manual</source>
        <translation>Ručne</translation>
    </message>
</context>
<context>
    <name>output::Task::UiUpdater</name>
    <message>
        <location filename="../filters/output/Task.cpp" line="506"/>
        <source>Picture zones are only available in Mixed mode.</source>
        <translation>Zóny obrázkov sú možné len v zmiešanom móde.</translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="558"/>
        <source>Despeckling can&apos;t be done in Color / Grayscale mode.</source>
        <translation>Čistenie nemožno použiť vo farebnom / šedom móde.</translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="575"/>
        <source>Output</source>
        <translation>Výstup</translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="576"/>
        <source>Picture Zones</source>
        <translation>Zóny obrázkov</translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="577"/>
        <source>Fill Zones</source>
        <translation>Prázdne zóny</translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="578"/>
        <source>Dewarping</source>
        <translation>Deformácie</translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="579"/>
        <source>Despeckling</source>
        <translation>Čistenie</translation>
    </message>
</context>
<context>
    <name>page_layout::ApplyDialog</name>
    <message>
        <location filename="../filters/page_layout/ApplyDialog.cpp" line="51"/>
        <source>Can&apos;t do: more than one group is selected.</source>
        <translation type="unfinished">Nemožno vykonať: je vybraná viac než jedna skupina.</translation>
    </message>
</context>
<context>
    <name>page_layout::Filter</name>
    <message>
        <location filename="../filters/page_layout/Filter.cpp" line="67"/>
        <source>Natural order</source>
        <translation>Postupné zoradenie</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/Filter.cpp" line="68"/>
        <source>Order by increasing width</source>
        <translation>Zoradiť podľa rastúcej šírky</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/Filter.cpp" line="69"/>
        <source>Order by increasing height</source>
        <translation>Zoradiť podľa rastúcej výšky</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/Filter.cpp" line="79"/>
        <source>Margins</source>
        <translation>Okraje</translation>
    </message>
</context>
<context>
    <name>page_layout::ImageView</name>
    <message>
        <location filename="../filters/page_layout/ImageView.cpp" line="76"/>
        <source>Resize margins by dragging any of the solid lines.</source>
        <translation>Zmeňte okraje ťahaním za ľubovoľný okraj.</translation>
    </message>
</context>
<context>
    <name>page_layout::OptionsWidget</name>
    <message>
        <location filename="../filters/page_layout/OptionsWidget.cpp" line="310"/>
        <source>Apply Margins</source>
        <translation>Použiť okraje</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/OptionsWidget.cpp" line="325"/>
        <source>Apply Alignment</source>
        <translation>Použiť zarovnanie</translation>
    </message>
</context>
<context>
    <name>page_split::Filter</name>
    <message>
        <location filename="../filters/page_split/Filter.cpp" line="65"/>
        <source>Natural order</source>
        <translation type="unfinished">Postupné zoradenie</translation>
    </message>
    <message>
        <location filename="../filters/page_split/Filter.cpp" line="66"/>
        <source>Order by split type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/page_split/Filter.cpp" line="76"/>
        <source>Split Pages</source>
        <translation>Orezať strany</translation>
    </message>
</context>
<context>
    <name>page_split::ImageView</name>
    <message>
        <location filename="../filters/page_split/ImageView.cpp" line="85"/>
        <source>Drag the line or the handles.</source>
        <translation>Ťahajte za okraj alebo za rukoväť.</translation>
    </message>
</context>
<context>
    <name>page_split::OptionsWidget</name>
    <message>
        <location filename="../filters/page_split/OptionsWidget.cpp" line="116"/>
        <location filename="../filters/page_split/OptionsWidget.cpp" line="208"/>
        <location filename="../filters/page_split/OptionsWidget.cpp" line="301"/>
        <source>Set manually</source>
        <translation>Nastaviť ručne</translation>
    </message>
    <message>
        <location filename="../filters/page_split/OptionsWidget.cpp" line="165"/>
        <location filename="../filters/page_split/OptionsWidget.cpp" line="298"/>
        <source>Auto detected</source>
        <translation>Autodetekcia</translation>
    </message>
</context>
<context>
    <name>page_split::UnremoveButton</name>
    <message>
        <location filename="../filters/page_split/UnremoveButton.cpp" line="38"/>
        <source>Restore removed page.</source>
        <translation>Obnoviť odstránenú stranu.</translation>
    </message>
</context>
<context>
    <name>select_content::ApplyDialog</name>
    <message>
        <location filename="../filters/select_content/ApplyDialog.cpp" line="53"/>
        <source>Can&apos;t do: more than one group is selected.</source>
        <translation type="unfinished">Nemožno vykonať: je vybraná viac než jedna skupina.</translation>
    </message>
</context>
<context>
    <name>select_content::Filter</name>
    <message>
        <location filename="../filters/select_content/Filter.cpp" line="59"/>
        <source>Natural order</source>
        <translation>Postupné zoradenie</translation>
    </message>
    <message>
        <location filename="../filters/select_content/Filter.cpp" line="60"/>
        <source>Order by increasing width</source>
        <translation>Zoradiť podľa rastúcej šírky</translation>
    </message>
    <message>
        <location filename="../filters/select_content/Filter.cpp" line="61"/>
        <source>Order by increasing height</source>
        <translation>Zoradiť podľa rastúcej výšky</translation>
    </message>
    <message>
        <location filename="../filters/select_content/Filter.cpp" line="71"/>
        <source>Select Content</source>
        <translation>Vybrať obsah</translation>
    </message>
</context>
<context>
    <name>select_content::ImageView</name>
    <message>
        <location filename="../filters/select_content/ImageView.cpp" line="58"/>
        <source>Use the context menu to enable / disable the content box.</source>
        <translation>Použite kontextové menu pre zapnutie alebo vypnutie obsahu.</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ImageView.cpp" line="61"/>
        <source>Drag lines or corners to resize the content box.</source>
        <translation>Výber obsahu zmeníte ťahaním za okraje alebo rohy.</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ImageView.cpp" line="107"/>
        <source>Create Content Box</source>
        <translation>Vytvoriť výber obsahu</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ImageView.cpp" line="108"/>
        <source>Remove Content Box</source>
        <translation>Odstrániť výber obsahu</translation>
    </message>
</context>
</TS>
